@@ -1,6 +1,10 @@
 package backend
 
 import (
+	"errors"
+	"os"
+	"time"
+
 	"github.com/rs/zerolog/log"
 
 	"0xacab.org/leap/bitmask-vpn/pkg/bitmask"
@@ -21,6 +25,11 @@ func initializeContext(opts *InitOpts) {
 	// multi-provider config in the backend too, and just
 	// switch the "active" here in the ctx, after the user has selected one
 	// in the combobox.
+
+	// if ctx is not nil then close the signal channel to break up the status update loop
+	if ctx != nil {
+		close(ctx.bm.GetStatusCloseCh())
+	}
 	ctx = &connectionCtx{
 		AppName:         opts.ProviderOptions.AppName,
 		Provider:        opts.ProviderOptions.Provider,
@@ -28,6 +37,7 @@ func initializeContext(opts *InitOpts) {
 		HelpURL:         opts.ProviderOptions.HelpURL,
 		DonateURL:       opts.ProviderOptions.DonateURL,
 		AskForDonations: opts.ProviderOptions.AskForDonations,
+		Providers:       opts.AvailableProviders,
 		DonateDialog:    false,
 		Version:         version.Version(),
 		Status:          st,
@@ -61,10 +71,15 @@ func initializeBitmask(errCh chan string, opts *InitOpts) {
 	ctx.UseUDP = ctx.cfg.UDP
 
 	err := pid.AcquirePID()
-	if err != nil {
-		log.Fatal().
+	if err != nil && errors.Is(err, pid.AlreadyRunningErr) {
+		log.Error().
 			Err(err).
 			Msg("Could not acquire PID")
+		errCh <- "alreadyrunning"
+		// would be better to quit the app from cpp land
+		// using go trigger(OnInitPidError)
+		time.Sleep(10 * time.Second)
+		os.Exit(1)
 	}
 
 	b, err := bitmask.InitializeBitmask(ctx.cfg)
@@ -74,9 +89,10 @@ func initializeBitmask(errCh chan string, opts *InitOpts) {
 			Err(err).
 			Msg("Could not initialize bitmask")
 		errCh <- err.Error()
-		return
 	}
 
+	ctx.bm = b
+
 	// right now we just get autostart from an init flag,
 	// but we want to be able to persist that option from the preferences
 	// pane
@@ -99,7 +115,6 @@ func initializeBitmask(errCh chan string, opts *InitOpts) {
 		log.Error().Msg("Could not find polkit")
 		errCh <- "nopolkit"
 	}
-	ctx.bm = b
 	ctx.IsReady = true
 }
 
@@ -127,7 +142,7 @@ func setConfigOpts(opts *InitOpts, conf *config.Config) {
 }
 
 func initializeAutostart(conf *config.Config) bitmaskAutostart.Autostart {
-	autostart := bitmaskAutostart.NewAutostart(config.ApplicationName, "")
+	autostart := bitmaskAutostart.NewAutostart(config.ProviderConfig.ApplicationName, "")
 	if conf.SkipLaunch || conf.DisableAutostart {
 		// Disable removes ~.config/autostart/RiseupVPN.desktop: (on Linux)
 		// it's possible that the file does not exist, so no need to check err
